@@ -2,9 +2,10 @@ import logging
 import os
 import traceback
 from time import sleep
-from datetime import datetime
+from datetime import datetime, timedelta
 from ..basic.core import SitesCore
 from .grouped_row import GroupedRow
+import SeleniumLibrary.errors
 
 
 class QuickbooksCore(SitesCore):
@@ -89,6 +90,50 @@ class QuickbooksCore(SitesCore):
                 self.browser.close_browser()
         return False
 
+    def wait_element(self, xpath: str, timeout: int = 60, is_need_screenshot: bool = True) -> bool:
+        """
+        Wait element some time.
+
+        :param xpath: Xpath of the element
+        :param timeout: How long to wait if the item does not appear?
+        :param is_need_screenshot: Do need to take a screenshot?
+        :return: True if element found, else False
+        """
+        is_success: bool = False
+        timer: datetime = datetime.now() + timedelta(seconds=timeout)
+
+        while not is_success and timer > datetime.now():
+            self.__close_specific_windows('//button[@aria-label="Close"]')
+
+            if self.browser.does_page_contain_element(xpath):
+                try:
+                    is_success = self.browser.find_element(xpath).is_displayed()
+                except SeleniumLibrary.errors.ElementNotFound:
+                    sleep(1)
+
+        if not is_success and is_need_screenshot:
+            now: datetime = datetime.now()
+            logging.warning(f'[{now.strftime("%H:%M:%S")}] Element \'{xpath}\' not available')
+            self.browser.capture_page_screenshot(
+                os.path.join(self.output_folder, f'Element_not_available_{now.strftime("%H_%M_%S")}.png')
+            )
+        return is_success
+
+    def __close_specific_windows(self, xpath: str) -> None:
+        if self.browser.does_page_contain_element(xpath):
+            elements: list = self.browser.find_elements(xpath)
+            for element in elements:
+                try:
+                    if element.is_displayed():
+                        logging.warning('A pop-up appeared and the bot closed it. Please validate the screenshot of the pop-up in the artifacts.')
+                        self.browser.capture_page_screenshot(
+                            os.path.join(self.output_folder, f'Pop_up_{datetime.now().strftime("%H_%M_%S")}.png')
+                        )
+                        element.click()
+                        self.browser.wait_until_element_is_not_visible(f'({xpath})[{elements.index(element) + 1}]')
+                except (AssertionError, SeleniumLibrary.errors.ElementNotFound):
+                    sleep(1)
+
     def go_to_client_page(self, client_name: str) -> None:
         """
         Navigate to client page
@@ -133,10 +178,10 @@ class QuickbooksCore(SitesCore):
             '//span[text()="Sales"]/..',
             '//a[text()="Invoices"]',
             '//th[@data-column-id="date"]',
-            '//input[@aria-label="textFieldWrapper" and not(@data-automation-id)]',
-            '//div[@value="paid"]',
-            '//input[@aria-label="textFieldWrapper" and @data-automation-id="date-dropdown"]',
-            '//div[@value="m:3"]',
+            '//div[contains(@class, "TextFieldWrapper")]//input[not(@data-automation-id)]',
+            '//li[text()="Paid"]',
+            '//div[contains(@class, "TextFieldWrapper")]//input[@data-automation-id="date-dropdown"]',
+            '//li[text()="Last 3 months"]',
         ])
         self.wait_element('//th[@data-column-id="date" and contains(@class, "sorted-desc")]', 5, False)
         if not self.browser.does_page_contain_element('//th[@data-column-id="date" and contains(@class, "sorted-desc")]'):
